#!/bin/sh

srcdir=`dirname $0`
test -z "$srcdir" && srcdir=.

autoreconf -i -f \
  && glib-gettextize -c -f \
  && intltoolize -c -f --automake
